@@ -22,6 +22,7 @@ DEFAULT_COORDINATES = 49.2, 16.616667  # Brno
 #(49.233056, 17.666944) is Zlin
 
 DEFAULT_THEME_ID = "default"
+DEFAULT_THEME_NAME = "Default"
 
 LOCATION_TIMEOUT = 30 # in seconds
 INTERNET_CONNECTIVITY_TIMEOUT = 30 # in seconds
@@ -76,3 +77,4 @@ ROUTE_CAR = 3
 
 # API access
 GOOGLE_API_KEY = 'ABQIAAAAv84YYgTIjdezewgb8xl5_xTKlax5G-CAZlpGqFgXfh-jq3S0yRS6XLrXE9CkHPS6KDCig4gHvHK3lw'
+GEONAMES_USERNAME = "modrana"
\ No newline at end of file
